summaryrefslogtreecommitdiffstats
path: root/src/H5SMmessage.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5SMmessage.c')
-rw-r--r--src/H5SMmessage.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/H5SMmessage.c b/src/H5SMmessage.c
index 5dbe5cf..426ea20 100644
--- a/src/H5SMmessage.c
+++ b/src/H5SMmessage.c
@@ -74,7 +74,7 @@ static herr_t H5SM_compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg, unsigned sequenc
/*-------------------------------------------------------------------------
* Function: H5SM_compare_cb
*
* Purpose: Callback for H5HF_op, used in H5SM_message_compare below.
* Determines whether the search key passed in in _UDATA is
* equal to OBJ or not.
*
@@ -170,7 +170,7 @@ done:
/*-------------------------------------------------------------------------
- * Function: H5SM_message_compare
+ * Function: H5SM__message_compare
*
* Purpose: Determine whether the search key rec1 represents a shared
* message that is equal to rec2 or not, and if not, whether
@@ -186,13 +186,13 @@ done:
*-------------------------------------------------------------------------
*/
herr_t
-H5SM_message_compare(const void *rec1, const void *rec2)
+H5SM__message_compare(const void *rec1, const void *rec2)
{
const H5SM_mesg_key_t *key = (const H5SM_mesg_key_t *) rec1;
const H5SM_sohm_t *mesg = (const H5SM_sohm_t *) rec2;
herr_t ret_value = 0;
- FUNC_ENTER_NOAPI_NOINIT_NOERR
+ FUNC_ENTER_PACKAGE_NOERR
/* If the key has an fheap ID, we're looking for a message that's
* already in the index; if the fheap ID matches, we've found the message
@@ -269,11 +269,11 @@ H5SM_message_compare(const void *rec1, const void *rec2)
done:
FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5SM_message_compare */
+} /* end H5SM__message_compare */
/*-------------------------------------------------------------------------
- * Function: H5SM_message_encode
+ * Function: H5SM__message_encode
*
* Purpose: Serialize a H5SM_sohm_t struct into a buffer RAW.
*
@@ -286,12 +286,12 @@ done:
*-------------------------------------------------------------------------
*/
herr_t
-H5SM_message_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
+H5SM__message_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
{
H5SM_bt2_ctx_t *ctx = (H5SM_bt2_ctx_t *)_ctx; /* Callback context structure */
const H5SM_sohm_t *message = (const H5SM_sohm_t *)_nrecord;
- FUNC_ENTER_NOAPI_NOINIT_NOERR
+ FUNC_ENTER_PACKAGE_NOERR
/* Sanity check */
HDassert(ctx);
@@ -313,11 +313,11 @@ H5SM_message_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
} /* end else */
FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5SM_message_encode */
+} /* end H5SM__message_encode */
/*-------------------------------------------------------------------------
- * Function: H5SM_message_decode
+ * Function: H5SM__message_decode
*
* Purpose: Read an encoded SOHM message from RAW into an H5SM_sohm_t struct.
*
@@ -330,12 +330,12 @@ H5SM_message_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
*-------------------------------------------------------------------------
*/
herr_t
-H5SM_message_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
+H5SM__message_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
{
H5SM_bt2_ctx_t *ctx = (H5SM_bt2_ctx_t *)_ctx; /* Callback context structure */
H5SM_sohm_t *message = (H5SM_sohm_t *)_nrecord;
- FUNC_ENTER_NOAPI_NOINIT_NOERR
+ FUNC_ENTER_PACKAGE_NOERR
message->location = (H5SM_storage_loc_t)*raw++;
UINT32DECODE(raw, message->hash);
@@ -354,5 +354,5 @@ H5SM_message_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
} /* end else */
FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5SM_message_decode */
+} /* end H5SM__message_decode */
@@ -74,7 +74,7 @@ static herr_t H5SM_compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg, unsigned sequenc
* Function: H5SM_compare_cb
*
- * Purpose: Callback for H5HF_op, used in H5SM_message_compare below.
+ * Purpose: Callback for H5HF_op, used in H5SM__message_compare below.
* Determines whether the search key passed in in _UDATA is
* equal to OBJ or not.